Pending
-------

* None

0.3.1
-----

* Uppercase BIC (Gunnar Scherf @g10f).
* Fix German translation (Gunnar Scherf @g10f).
* Latvian and Russian translations (@vgaicuks).

0.3.0
-----

* Pull in IBAN related code that has been contributed django-localflavor. Thanks to Erik Romijn for the code review
  and bug fixes.
* IBANField uses IBANFormField by default.
* IBAN display format (with spaces) is used in the IBANFormField.
* Optionally limit validation to a list specific of countries.
* Various bug fixes.

0.2.8
-----

* Fix translations for bg, de, fr, nl and pl (Paweł Nowak).

0.2.7
-----

* Allow IBANs to have spaces as per the official display representation.
* Bug fix to re-enable translations (Rodrigo Olmo).
* Add Spanish translations (Rodrigo Olmo).

0.2.6
-----

* Python 3.3 support (lucvandort).
* Python 3.2 support.
* Remove date conditional IBANs. Pending IBANs are now always included in validation.
* Add optional support for the Nordea IBAN extensions.

0.2.5
-----

* Add support for django-countries >= 2.0 (Steffen Zieger).

0.2.4
-----

* Include the translations in the distribution.

0.2.3
-----

* Remove incorrect IBAN aliases for French islands.
* Add date conditional support for Qatar IBAN.

0.2.2
-----

* Add form fields.
* Add Dutch translations.
* Add French translations.
* Move Brazil to official IBAN list.
* Add Polish translations.

0.2.1
-----

* Add German translations.
* Add Bulgarian translations.

0.2.0
-----

* **API change** Rename IbanAccountField to IBANField.
* Add SWIFTBICField.

0.1.5
-----

* Add usage instructions to the README.

0.1.4
-----

* Add date conditional support for Brazil IBAN.
* Move Pakistan to official IBAN list.

0.1.3
-----

* Add support for South.

0.1.2
-----

* Convert README to rst.

0.1.1
-----

* Include README in distribution.


0.1
---

* Initial release with validated IBAN model field.
